==> nextcloud-24.0.11.tgz: nextcloud/apps/photos/l10n/eu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Esteka publikoa",
    "Photos" : "Argazkiak",
    "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
    "All media" : "Fitxategi guztiak",
    "Videos" : "Bideoak",
    "Albums" : "Albumak",
    "Collaborative albums" : "Elkarlaneko albumak",
    "People" : "Jendea",
    "Folders" : "Karpetak",
    "Favorites" : "Gogokoak",
    "On this day" : "Egun honetan",
    "Shared with you" : "Zurekin partekatua",
    "Tags" : "Etiketak",
    "Places" : "Lekuak",
    "Map" : "Mapa",
    "Photos settings" : "Argazkien ezarpenak",
    "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
    "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
    "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
    "Name of the album" : "Albumaren izena",
    "Location of the album" : "Albumaren kokapena",
    "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
    "Back" : "Atzera",
    "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
    "Add collaborators" : "Gehitu kolaboratzaileak",
    "Save." : "Gorde.",
    "Create the album." : "Sortu albuma.",
    "Save" : "Gorde",
    "Create album" : "Sortu albuma",
    "Back to the new album form." : "Itzuli album berrien formulariora",
    "Add to Album" : "Gehitu album batera",
    "Add selection to album {albumName}" : "Gehitu hautapena {albumName} albumera",
    "Create a new album." : "Sortu album berria.",
    "Create new album" : "Sortu album berria",
    "New album" : "Album berria",
    "_%n item_::_%n photos and videos_" : ["%n fitxategi","%n argazki eta bideo"],
    "_Share with %n user_::_Share with %n users_" : ["Partekatu %n erabiltzailearekin","Partekatu %n erabiltzaileekin"],
    "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
    "Search for collaborators" : "Bilatu kolaboratzaileak",
    "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
    "Add {collaboratorLabel} to the collaborators list" : "Gehitu {collaboratorLabel} kolaboratzaile zerrendara",
    "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
    "Copy the public link" : "Kopiatu esteka publikoa",
    "Public link copied!" : "Esteka publikoa kopiatuta!",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Delete the public link" : "Ezabatu esteka publikoa",
    "Share via public link" : "Partekatu esteka publiko bidez",
    "Failed to fetch collaborators list." : "Ezin izan da kolaboratzaile zerrenda lortu.",
    "Failed to fetch album." : "Ezin izan da albuma lortu.",
    "Failed to update album." : "Ezin izan da albuma eguneratu.",
    "This collection does not exist" : "Bilduma hau ez da existitzen",
    "An error occurred" : "Errore bat gertatu da",
    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
    "Select image {imageName}" : "Hautatu irudia {imageName}",
    "The file is in the favorites" : "Fitxategia gogokoetan dago",
    "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
    "Add to {destination}" : "Gehitu hona: {destination}",
    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
    "Back to {folder}" : "Itzuli {folder}(e)ra",
    "Share this folder" : "Partekatu karpeta hau",
    "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
    "View" : "Ikusi",
    "Photos directory" : "Argazkien direktorioa",
    "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
    "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
    "Open actions menu" : "Ireki ekintzen menua",
    "Edit album details" : "Editatu albumaren xehetasunak",
    "Download all files in album" : "Deskargatu albumeko fitxategi guztiak",
    "Delete album" : "Ezabatu albuma",
    "Download selected files" : "Deskargatu hautatutakoak",
    "Remove selection from album" : "Kendu hautatutakoak albumetik",
    "This album does not have any photos or videos yet!" : "Album honek ez du argazki edo bideorik oraindik!",
    "Add photos to this album" : "Gehitu argazkiak album honetara ",
    "Add photos to the album" : "Gehitu argazkiak albumera",
    "Manage collaborators" : "Kudeatu kolaboratzaileak",
    "Save collaborators for this album." : "Gorde album honen kolaboratzaileak.",
    "Cover photo for album {albumName}" : "{albumName} albumaren azaleko argazkia",
    "There is no album yet!" : "Ez dago albumik oraindik!",
    "This person could not be found" : "Ezin izan da pertsona hori aurkitu",
    "Rename person" : "Berridatzi pertsonaren izena",
    "Merge with different person" : "Bateratu beste pertsona batekin",
    "Download selected photos" : "Deskargatu hautatutako argazkiak",
    "Favorite" : "Egin gogoko",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Remove person" : "Kendu pertsona",
    "Name of this person" : "Pertsona honen izena",
    "Merge person" : "Bateratu pertsona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mugitu argazkia beste pertsona batera","Mugitu argazkiak beste pertsona batera"],
    "_Remove photo from person_::_Remove photos from person_" : ["Kendu argazkia pertsonatik","Kendu argazkiak pertsonatik"],
    "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
    "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
    "This folder does not exist" : "Karpeta hau ez da existitzen",
    "Loading folders …" : "Karpetak kargatzen ...",
    "No photos in here" : "Argazkirik ez hemen",
    "Add photos to this place" : "Gehitu argazkiak leku honetara",
    "Failed to fetch albums list." : "Ezin izan da album zerrenda eskuratu.",
    "Shared albums" : "Partekaturiko albumak",
    "Cover photo for shared album {albumName}." : "{albumName} album partekatuko azaleko argazkia",
    "Back to tags overview" : "Itzuli etiketen ikuspegira",
    "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
    "No tags yet" : "Etitketarik ez oraindik",
    "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
    "Popular tags" : "Etiketa ohikoak",
    "Add" : "Gehitu",
    "Create a new album" : "Sortu album berri bat",
    "Add selection to an album" : "Gehitu hautatutakoak album batera",
    "Add to album" : "Gehitu albumera",
    "Delete selection" : "Ezabatu hautatutakoak",
    "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
    "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
    "All your media" : "Zure multimedia guztia",
    "Album {title}" : "{title} albuma",
    "Shared Albums" : "Partekatutako albumak",
    "Shared album {title}" : "{title} partekatutako albuma",
    "Public album {title}" : "{title} album publikoa",
    "Tagged photos" : "Etiketaturiko argazkiak",
    "Tagged photo {title}" : "{title} etiketaturiko argazkia",
    "{title}'s face" : "{title}(r)en aurpegia",
    "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa.",
    "Failed to rename {oldName} to {faceName}." : "Ezin izan da {oldName} berrizendatu {faceName} gisa.",
    "Failed to delete {faceName}." : "Ezin izan da  {faceName} ezabatu.",
    "Failed to delete {fileId}." : "{fileId} ezabatzeak huts egin du.",
    "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
    "Your photos" : "Zure argazkiak",
    "Your videos" : "Zure bideoak",
    "Your folders" : "Zure karpetak",
    "Locations" : "Kokapenak",
    "Settings" : "Ezarpenak"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.12.tgz: nextcloud/apps/photos/l10n/eu.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Esteka publikoa",
    "Photos" : "Argazkiak",
    "Your memories under your control" : "Zure oroitzapenak zure kontrolpean",
    "All media" : "Fitxategi guztiak",
    "Videos" : "Bideoak",
    "Albums" : "Albumak",
    "Collaborative albums" : "Elkarlaneko albumak",
    "People" : "Jendea",
    "Folders" : "Karpetak",
    "Favorites" : "Gogokoak",
    "On this day" : "Egun honetan",
    "Shared with you" : "Zurekin partekatua",
    "Tags" : "Etiketak",
    "Places" : "Lekuak",
    "Map" : "Mapa",
    "Photos settings" : "Argazkien ezarpenak",
    "Mark selection as favorite" : "Markatu hautatutakoak gogoko gisa",
    "Add selection to favorites" : "Gehitu hautatutakoak gogokoetara",
    "Remove selection from favorites" : "Kendu hautatutakoak gogokoetatik",
    "Name of the album" : "Albumaren izena",
    "Location of the album" : "Albumaren kokapena",
    "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
    "Back" : "Atzera",
    "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
    "Add collaborators" : "Gehitu kolaboratzaileak",
    "Save." : "Gorde.",
    "Create the album." : "Sortu albuma.",
    "Save" : "Gorde",
    "Create album" : "Sortu albuma",
    "Back to the new album form." : "Itzuli album berrien formulariora",
    "Add to Album" : "Gehitu album batera",
    "Add selection to album {albumName}" : "Gehitu hautapena {albumName} albumera",
    "Create a new album." : "Sortu album berria.",
    "Create new album" : "Sortu album berria",
    "New album" : "Album berria",
    "_%n item_::_%n photos and videos_" : ["%n fitxategi","%n argazki eta bideo"],
    "_Share with %n user_::_Share with %n users_" : ["Partekatu %n erabiltzailearekin","Partekatu %n erabiltzaileekin"],
    "Add people or groups who can edit your album" : "Gehitu zure albuma editatu dezaketen pertsona edo taldeak",
    "Search for collaborators" : "Bilatu kolaboratzaileak",
    "Search people or groups" : "Bilatu erabiltzaile edo taldeak",
    "Add {collaboratorLabel} to the collaborators list" : "Gehitu {collaboratorLabel} kolaboratzaile zerrendara",
    "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
    "Remove {collaboratorLabel} from the collaborators list" : "Kendu {collaboratorLabel} kolaboratzaile zerrendatik",
    "Copy the public link" : "Kopiatu esteka publikoa",
    "Public link copied!" : "Esteka publikoa kopiatuta!",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Delete the public link" : "Ezabatu esteka publikoa",
    "Share via public link" : "Partekatu esteka publiko bidez",
    "Failed to fetch collaborators list." : "Ezin izan da kolaboratzaile zerrenda lortu.",
    "Failed to fetch album." : "Ezin izan da albuma lortu.",
    "Failed to update album." : "Ezin izan da albuma eguneratu.",
    "This collection does not exist" : "Bilduma hau ez da existitzen",
    "An error occurred" : "Errore bat gertatu da",
    "_%n photos_::_%n photos_" : ["argazki %n","%n argazki"],
    "Select image {imageName}" : "Hautatu irudia {imageName}",
    "The file is in the favorites" : "Fitxategia gogokoetan dago",
    "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
    "Add to {destination}" : "Gehitu hona: {destination}",
    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
    "Back to {folder}" : "Itzuli {folder}(e)ra",
    "Share this folder" : "Partekatu karpeta hau",
    "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
    "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
    "View" : "Ikusi",
    "Photos directory" : "Argazkien direktorioa",
    "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
    "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
    "Open actions menu" : "Ireki ekintzen menua",
    "Edit album details" : "Editatu albumaren xehetasunak",
    "Download all files in album" : "Deskargatu albumeko fitxategi guztiak",
    "Delete album" : "Ezabatu albuma",
    "Download selected files" : "Deskargatu hautatutakoak",
    "Remove selection from album" : "Kendu hautatutakoak albumetik",
    "This album does not have any photos or videos yet!" : "Album honek ez du argazki edo bideorik oraindik!",
    "Add photos to this album" : "Gehitu argazkiak album honetara ",
    "Add photos to the album" : "Gehitu argazkiak albumera",
    "Manage collaborators" : "Kudeatu kolaboratzaileak",
    "Save collaborators for this album." : "Gorde album honen kolaboratzaileak.",
    "Cover photo for album {albumName}" : "{albumName} albumaren azaleko argazkia",
    "There is no album yet!" : "Ez dago albumik oraindik!",
    "This person could not be found" : "Ezin izan da pertsona hori aurkitu",
    "Rename person" : "Berridatzi pertsonaren izena",
    "Merge with different person" : "Bateratu beste pertsona batekin",
    "Download selected photos" : "Deskargatu hautatutako argazkiak",
    "Favorite" : "Egin gogoko",
    "Remove from favorites" : "Kendu gogokoetatik",
    "Remove person" : "Kendu pertsona",
    "Name of this person" : "Pertsona honen izena",
    "Merge person" : "Bateratu pertsona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mugitu argazkia beste pertsona batera","Mugitu argazkiak beste pertsona batera"],
    "_Remove photo from person_::_Remove photos from person_" : ["Kendu argazkia pertsonatik","Kendu argazkiak pertsonatik"],
    "This might take some time depending on the size of your photo library." : "Honek luze jo dezake, zure argazki liburutegiaren tamainaren arabera.",
    "Recognized people will show up here" : "Ezagutu diren pertsonak hemen agertuko dira",
    "This folder does not exist" : "Karpeta hau ez da existitzen",
    "Loading folders …" : "Karpetak kargatzen ...",
    "No photos in here" : "Argazkirik ez hemen",
    "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
    "Add photos to this place" : "Gehitu argazkiak leku honetara",
    "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
    "There is no place yet!" : "Oraindik ez dago lekurik!",
    "Failed to fetch albums list." : "Ezin izan da album zerrenda eskuratu.",
    "Shared albums" : "Partekaturiko albumak",
    "Cover photo for shared album {albumName}." : "{albumName} album partekatuko azaleko argazkia",
    "Back to tags overview" : "Itzuli etiketen ikuspegira",
    "No photos with this tag yet" : "Ez dago etiketa hau duen argazkirik oraindik",
    "No tags yet" : "Etitketarik ez oraindik",
    "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
    "Popular tags" : "Etiketa ohikoak",
    "Add" : "Gehitu",
    "Create a new album" : "Sortu album berri bat",
    "Add selection to an album" : "Gehitu hautatutakoak album batera",
    "Add to album" : "Gehitu albumera",
    "Delete selection" : "Ezabatu hautatutakoak",
    "No photos or videos in here" : "Ez dago argazki edo bideorik hemen",
    "Failed to fetch collection." : "Ezin izan da bilduma eskuratu.",
    "Failed to fetch collections list." : "Ezin izan da bildumen zerrenda eskuratu.",
    "Failed to fetch faces list." : "Ezin izan da aurpegien zerrenda eskuratu.",
    "All your media" : "Zure multimedia guztia",
    "Album {title}" : "{title} albuma",
    "Shared Albums" : "Partekatutako albumak",
    "Shared album {title}" : "{title} partekatutako albuma",
    "Public album {title}" : "{title} album publikoa",
    "Tagged photos" : "Etiketaturiko argazkiak",
    "Tagged photo {title}" : "{title} etiketaturiko argazkia",
    "{title}'s face" : "{title}(r)en aurpegia",
    "Failed to create {albumName}." : "Ezin izan da {albumName} sortu.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Ezin izan da {currentAlbumName} berrizendatu {newAlbumName} gisa.",
    "Failed to rename {oldName} to {faceName}." : "Ezin izan da {oldName} berrizendatu {faceName} gisa.",
    "Failed to delete {faceName}." : "Ezin izan da  {faceName} ezabatu.",
    "Failed to delete {fileId}." : "{fileId} ezabatzeak huts egin du.",
    "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
    "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
    "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
    "Your photos" : "Zure argazkiak",
    "Your videos" : "Zure bideoak",
    "Your folders" : "Zure karpetak",
    "Locations" : "Kokapenak",
    "Settings" : "Ezarpenak"
},
"nplurals=2; plural=(n != 1);");
